# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SchemaMessages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14SchemaMessages.proto\x12\x03xgt\x1a\x13\x45rrorMessages.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x95\x01\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\tdata_type\x18\x02 \x01(\x0e\x32\x11.xgt.UvalTypeEnum\x12\x1b\n\x04role\x18\x03 \x01(\x0e\x32\r.xgt.RoleEnum\x12$\n\tleaf_type\x18\x04 \x01(\x0e\x32\x11.xgt.UvalTypeEnum\x12\x12\n\nlist_depth\x18\x05 \x01(\x04\")\n\x06Schema\x12\x1f\n\x08property\x18\x01 \x03(\x0b\x32\r.xgt.Property\"7\n\nTableFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x06schema\x18\x02 \x01(\x0b\x32\x0b.xgt.Schema\"8\n\x0bVertexFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x06schema\x18\x02 \x01(\x0b\x32\x0b.xgt.Schema\"\x8c\x01\n\tEdgeFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x06schema\x18\x02 \x01(\x0b\x32\x0b.xgt.Schema\x12\x15\n\rsource_vertex\x18\x03 \x01(\t\x12\x15\n\rtarget_vertex\x18\x04 \x01(\t\x12\x12\n\nsource_key\x18\x05 \x01(\t\x12\x12\n\ntarget_key\x18\x06 \x01(\t\"\xc7\x01\n\x08\x41nyFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x06schema\x18\x02 \x01(\x0b\x32\x0b.xgt.Schema\x12\x15\n\rsource_vertex\x18\x03 \x01(\t\x12\x15\n\rtarget_vertex\x18\x04 \x01(\t\x12\x12\n\nsource_key\x18\x05 \x01(\t\x12\x12\n\ntarget_key\x18\x06 \x01(\t\x12\x14\n\x0c\x63ontainer_id\x18\x08 \x01(\x04\x12\x11\n\tcommit_id\x18\t \x01(\x04\x12\x11\n\tdelete_id\x18\n \x01(\x04\"\xc3\x01\n\x10QueryEdgeMessage\x12/\n\x0e\x65\x64ge_direction\x18\x01 \x01(\x0e\x32\x17.xgt.QueryEdgeDirection\x12\x12\n\nedge_label\x18\x02 \x01(\t\x12\x12\n\nedge_frame\x18\x03 \x01(\t\x12\x14\n\x0csource_label\x18\x04 \x01(\t\x12\x14\n\x0csource_frame\x18\x05 \x01(\t\x12\x14\n\x0ctarget_label\x18\x06 \x01(\t\x12\x14\n\x0ctarget_frame\x18\x07 \x01(\t\"]\n\rQueryEdgeList\x12$\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x15.xgt.QueryEdgeMessage\x12\x17\n\nplan_score\x18\x02 \x01(\x01H\x00\x88\x01\x01\x42\r\n\x0b_plan_score\":\n\tQueryPlan\x12-\n\x11plan_as_edge_list\x18\x01 \x03(\x0b\x32\x12.xgt.QueryEdgeList\"\xe1\x03\n\tJobStatus\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0e\n\x06job_id\x18\x02 \x01(\x04\x12\"\n\x06status\x18\x03 \x01(\x0e\x32\x12.xgt.JobStatusEnum\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x37\n\rvisited_edges\x18\x08 \x03(\x0b\x32 .xgt.JobStatus.VisitedEdgesEntry\x12\x0e\n\x06timing\x18\t \x03(\t\x12\x1b\n\x06schema\x18\n \x01(\x0b\x32\x0b.xgt.Schema\x12\x12\n\ntotal_rows\x18\x0b \x01(\x04\x12\"\n\nquery_plan\x18\x0c \x01(\x0b\x32\x0e.xgt.QueryPlan\x12\x1b\n\x13total_ingest_errors\x18\r \x01(\x04\x12\x14\n\x0cingest_error\x18\x0e \x03(\t\x1a\x33\n\x11VisitedEdgesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01*\xd0\x01\n\x0cUvalTypeEnum\x12\x15\n\x11UNKNOWN_UVAL_TYPE\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07\x42OOLEAN\x10\x02\x12\x07\n\x03INT\x10\x03\x12\t\n\x05\x46LOAT\x10\x04\x12\x08\n\x04\x44\x41TE\x10\x05\x12\x08\n\x04TIME\x10\x06\x12\x0c\n\x08\x44\x41TETIME\x10\x07\x12\r\n\tIPADDRESS\x10\x08\x12\x08\n\x04TEXT\x10\t\x12\x10\n\x0c\x43ONTAINER_ID\x10\n\x12\n\n\x06JOB_ID\x10\x0b\x12\x08\n\x04LIST\x10\x0c\x12\n\n\x06ROW_ID\x10\r\x12\x0c\n\x08\x44URATION\x10\x0e*q\n\x08RoleEnum\x12\x0c\n\x08PROPERTY\x10\x00\x12\x0e\n\nVERTEX_KEY\x10\x01\x12\x13\n\x0f\x45\x44GE_SOURCE_KEY\x10\x02\x12\x13\n\x0f\x45\x44GE_TARGET_KEY\x10\x03\x12\x1d\n\x19\x41SSOCIATIVE_CONTAINER_KEY\x10\x04*F\n\rFrameTypeEnum\x12\t\n\x05TABLE\x10\x00\x12\n\n\x06VERTEX\x10\x01\x12\x08\n\x04\x45\x44GE\x10\x02\x12\x14\n\x10UVAL_ASSOCIATIVE\x10\x03*z\n\rJobStatusEnum\x12\x16\n\x12UNKNOWN_JOB_STATUS\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0c\n\x08ROLLBACK\x10\x06*=\n\x12QueryEdgeDirection\x12\x0b\n\x07\x46ORWARD\x10\x00\x12\x0c\n\x08\x42\x41\x43KWARD\x10\x01\x12\x0c\n\x08NOT_EDGE\x10\x02\x62\x06proto3')

_UVALTYPEENUM = DESCRIPTOR.enum_types_by_name['UvalTypeEnum']
UvalTypeEnum = enum_type_wrapper.EnumTypeWrapper(_UVALTYPEENUM)
_ROLEENUM = DESCRIPTOR.enum_types_by_name['RoleEnum']
RoleEnum = enum_type_wrapper.EnumTypeWrapper(_ROLEENUM)
_FRAMETYPEENUM = DESCRIPTOR.enum_types_by_name['FrameTypeEnum']
FrameTypeEnum = enum_type_wrapper.EnumTypeWrapper(_FRAMETYPEENUM)
_JOBSTATUSENUM = DESCRIPTOR.enum_types_by_name['JobStatusEnum']
JobStatusEnum = enum_type_wrapper.EnumTypeWrapper(_JOBSTATUSENUM)
_QUERYEDGEDIRECTION = DESCRIPTOR.enum_types_by_name['QueryEdgeDirection']
QueryEdgeDirection = enum_type_wrapper.EnumTypeWrapper(_QUERYEDGEDIRECTION)
UNKNOWN_UVAL_TYPE = 0
UNKNOWN = 1
BOOLEAN = 2
INT = 3
FLOAT = 4
DATE = 5
TIME = 6
DATETIME = 7
IPADDRESS = 8
TEXT = 9
CONTAINER_ID = 10
JOB_ID = 11
LIST = 12
ROW_ID = 13
DURATION = 14
PROPERTY = 0
VERTEX_KEY = 1
EDGE_SOURCE_KEY = 2
EDGE_TARGET_KEY = 3
ASSOCIATIVE_CONTAINER_KEY = 4
TABLE = 0
VERTEX = 1
EDGE = 2
UVAL_ASSOCIATIVE = 3
UNKNOWN_JOB_STATUS = 0
SCHEDULED = 1
RUNNING = 2
COMPLETED = 3
CANCELED = 4
FAILED = 5
ROLLBACK = 6
FORWARD = 0
BACKWARD = 1
NOT_EDGE = 2


_PROPERTY = DESCRIPTOR.message_types_by_name['Property']
_SCHEMA = DESCRIPTOR.message_types_by_name['Schema']
_TABLEFRAME = DESCRIPTOR.message_types_by_name['TableFrame']
_VERTEXFRAME = DESCRIPTOR.message_types_by_name['VertexFrame']
_EDGEFRAME = DESCRIPTOR.message_types_by_name['EdgeFrame']
_ANYFRAME = DESCRIPTOR.message_types_by_name['AnyFrame']
_QUERYEDGEMESSAGE = DESCRIPTOR.message_types_by_name['QueryEdgeMessage']
_QUERYEDGELIST = DESCRIPTOR.message_types_by_name['QueryEdgeList']
_QUERYPLAN = DESCRIPTOR.message_types_by_name['QueryPlan']
_JOBSTATUS = DESCRIPTOR.message_types_by_name['JobStatus']
_JOBSTATUS_VISITEDEDGESENTRY = _JOBSTATUS.nested_types_by_name['VisitedEdgesEntry']
Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTY,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Property)
  })
_sym_db.RegisterMessage(Property)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Schema)
  })
_sym_db.RegisterMessage(Schema)

TableFrame = _reflection.GeneratedProtocolMessageType('TableFrame', (_message.Message,), {
  'DESCRIPTOR' : _TABLEFRAME,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.TableFrame)
  })
_sym_db.RegisterMessage(TableFrame)

VertexFrame = _reflection.GeneratedProtocolMessageType('VertexFrame', (_message.Message,), {
  'DESCRIPTOR' : _VERTEXFRAME,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VertexFrame)
  })
_sym_db.RegisterMessage(VertexFrame)

EdgeFrame = _reflection.GeneratedProtocolMessageType('EdgeFrame', (_message.Message,), {
  'DESCRIPTOR' : _EDGEFRAME,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.EdgeFrame)
  })
_sym_db.RegisterMessage(EdgeFrame)

AnyFrame = _reflection.GeneratedProtocolMessageType('AnyFrame', (_message.Message,), {
  'DESCRIPTOR' : _ANYFRAME,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.AnyFrame)
  })
_sym_db.RegisterMessage(AnyFrame)

QueryEdgeMessage = _reflection.GeneratedProtocolMessageType('QueryEdgeMessage', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEDGEMESSAGE,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.QueryEdgeMessage)
  })
_sym_db.RegisterMessage(QueryEdgeMessage)

QueryEdgeList = _reflection.GeneratedProtocolMessageType('QueryEdgeList', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEDGELIST,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.QueryEdgeList)
  })
_sym_db.RegisterMessage(QueryEdgeList)

QueryPlan = _reflection.GeneratedProtocolMessageType('QueryPlan', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPLAN,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.QueryPlan)
  })
_sym_db.RegisterMessage(QueryPlan)

JobStatus = _reflection.GeneratedProtocolMessageType('JobStatus', (_message.Message,), {

  'VisitedEdgesEntry' : _reflection.GeneratedProtocolMessageType('VisitedEdgesEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOBSTATUS_VISITEDEDGESENTRY,
    '__module__' : 'SchemaMessages_pb2'
    # @@protoc_insertion_point(class_scope:xgt.JobStatus.VisitedEdgesEntry)
    })
  ,
  'DESCRIPTOR' : _JOBSTATUS,
  '__module__' : 'SchemaMessages_pb2'
  # @@protoc_insertion_point(class_scope:xgt.JobStatus)
  })
_sym_db.RegisterMessage(JobStatus)
_sym_db.RegisterMessage(JobStatus.VisitedEdgesEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOBSTATUS_VISITEDEDGESENTRY._options = None
  _JOBSTATUS_VISITEDEDGESENTRY._serialized_options = b'8\001'
  _UVALTYPEENUM._serialized_start=1576
  _UVALTYPEENUM._serialized_end=1784
  _ROLEENUM._serialized_start=1786
  _ROLEENUM._serialized_end=1899
  _FRAMETYPEENUM._serialized_start=1901
  _FRAMETYPEENUM._serialized_end=1971
  _JOBSTATUSENUM._serialized_start=1973
  _JOBSTATUSENUM._serialized_end=2095
  _QUERYEDGEDIRECTION._serialized_start=2097
  _QUERYEDGEDIRECTION._serialized_end=2158
  _PROPERTY._serialized_start=84
  _PROPERTY._serialized_end=233
  _SCHEMA._serialized_start=235
  _SCHEMA._serialized_end=276
  _TABLEFRAME._serialized_start=278
  _TABLEFRAME._serialized_end=333
  _VERTEXFRAME._serialized_start=335
  _VERTEXFRAME._serialized_end=391
  _EDGEFRAME._serialized_start=394
  _EDGEFRAME._serialized_end=534
  _ANYFRAME._serialized_start=537
  _ANYFRAME._serialized_end=736
  _QUERYEDGEMESSAGE._serialized_start=739
  _QUERYEDGEMESSAGE._serialized_end=934
  _QUERYEDGELIST._serialized_start=936
  _QUERYEDGELIST._serialized_end=1029
  _QUERYPLAN._serialized_start=1031
  _QUERYPLAN._serialized_end=1089
  _JOBSTATUS._serialized_start=1092
  _JOBSTATUS._serialized_end=1573
  _JOBSTATUS_VISITEDEDGESENTRY._serialized_start=1522
  _JOBSTATUS_VISITEDEDGESENTRY._serialized_end=1573
# @@protoc_insertion_point(module_scope)
