# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: JobService.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import AdminService_pb2 as AdminService__pb2
from . import ErrorMessages_pb2 as ErrorMessages__pb2
from . import SchemaMessages_pb2 as SchemaMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10JobService.proto\x12\x03xgt\x1a\x12\x41\x64minService.proto\x1a\x13\x45rrorMessages.proto\x1a\x14SchemaMessages.proto\"\xba\x02\n\x19ScheduleJobsCypherRequest\x12\x14\n\x0c\x63ypher_query\x18\x01 \x03(\t\x12:\n\x06kwargs\x18\x05 \x03(\x0b\x32*.xgt.ScheduleJobsCypherRequest.KwargsEntry\x12\x42\n\nparameters\x18\x06 \x03(\x0b\x32..xgt.ScheduleJobsCypherRequest.ParametersEntry\x1a?\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\x1a\x46\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.xgt.ParameterValue:\x02\x38\x01\"[\n\x1aScheduleJobsCypherResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus\"#\n\x11\x43\x61ncelJobsRequest\x12\x0e\n\x06job_id\x18\x01 \x03(\x04\"S\n\x12\x43\x61ncelJobsResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus\" \n\x0eGetJobsRequest\x12\x0e\n\x06job_id\x18\x01 \x03(\x04\"P\n\x0fGetJobsResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x01(\x0b\x32\x0e.xgt.JobStatus\"2\n\x0fWaitJobsRequest\x12\x0e\n\x06job_id\x18\x01 \x03(\x04\x12\x0f\n\x07timeout\x18\x02 \x01(\x03\"Q\n\x10WaitJobsResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x03(\x0b\x32\x0e.xgt.JobStatus2\x9b\x02\n\nJobService\x12W\n\x12ScheduleJobsCypher\x12\x1e.xgt.ScheduleJobsCypherRequest\x1a\x1f.xgt.ScheduleJobsCypherResponse\"\x00\x12?\n\nCancelJobs\x12\x16.xgt.CancelJobsRequest\x1a\x17.xgt.CancelJobsResponse\"\x00\x12\x38\n\x07GetJobs\x12\x13.xgt.GetJobsRequest\x1a\x14.xgt.GetJobsResponse\"\x00\x30\x01\x12\x39\n\x08WaitJobs\x12\x14.xgt.WaitJobsRequest\x1a\x15.xgt.WaitJobsResponse\"\x00\x62\x06proto3')



_SCHEDULEJOBSCYPHERREQUEST = DESCRIPTOR.message_types_by_name['ScheduleJobsCypherRequest']
_SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY = _SCHEDULEJOBSCYPHERREQUEST.nested_types_by_name['KwargsEntry']
_SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY = _SCHEDULEJOBSCYPHERREQUEST.nested_types_by_name['ParametersEntry']
_SCHEDULEJOBSCYPHERRESPONSE = DESCRIPTOR.message_types_by_name['ScheduleJobsCypherResponse']
_CANCELJOBSREQUEST = DESCRIPTOR.message_types_by_name['CancelJobsRequest']
_CANCELJOBSRESPONSE = DESCRIPTOR.message_types_by_name['CancelJobsResponse']
_GETJOBSREQUEST = DESCRIPTOR.message_types_by_name['GetJobsRequest']
_GETJOBSRESPONSE = DESCRIPTOR.message_types_by_name['GetJobsResponse']
_WAITJOBSREQUEST = DESCRIPTOR.message_types_by_name['WaitJobsRequest']
_WAITJOBSRESPONSE = DESCRIPTOR.message_types_by_name['WaitJobsResponse']
ScheduleJobsCypherRequest = _reflection.GeneratedProtocolMessageType('ScheduleJobsCypherRequest', (_message.Message,), {

  'KwargsEntry' : _reflection.GeneratedProtocolMessageType('KwargsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY,
    '__module__' : 'JobService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherRequest.KwargsEntry)
    })
  ,

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY,
    '__module__' : 'JobService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherRequest.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _SCHEDULEJOBSCYPHERREQUEST,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherRequest)
  })
_sym_db.RegisterMessage(ScheduleJobsCypherRequest)
_sym_db.RegisterMessage(ScheduleJobsCypherRequest.KwargsEntry)
_sym_db.RegisterMessage(ScheduleJobsCypherRequest.ParametersEntry)

ScheduleJobsCypherResponse = _reflection.GeneratedProtocolMessageType('ScheduleJobsCypherResponse', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEJOBSCYPHERRESPONSE,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ScheduleJobsCypherResponse)
  })
_sym_db.RegisterMessage(ScheduleJobsCypherResponse)

CancelJobsRequest = _reflection.GeneratedProtocolMessageType('CancelJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELJOBSREQUEST,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CancelJobsRequest)
  })
_sym_db.RegisterMessage(CancelJobsRequest)

CancelJobsResponse = _reflection.GeneratedProtocolMessageType('CancelJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELJOBSRESPONSE,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CancelJobsResponse)
  })
_sym_db.RegisterMessage(CancelJobsResponse)

GetJobsRequest = _reflection.GeneratedProtocolMessageType('GetJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBSREQUEST,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetJobsRequest)
  })
_sym_db.RegisterMessage(GetJobsRequest)

GetJobsResponse = _reflection.GeneratedProtocolMessageType('GetJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBSRESPONSE,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetJobsResponse)
  })
_sym_db.RegisterMessage(GetJobsResponse)

WaitJobsRequest = _reflection.GeneratedProtocolMessageType('WaitJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WAITJOBSREQUEST,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.WaitJobsRequest)
  })
_sym_db.RegisterMessage(WaitJobsRequest)

WaitJobsResponse = _reflection.GeneratedProtocolMessageType('WaitJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WAITJOBSRESPONSE,
  '__module__' : 'JobService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.WaitJobsResponse)
  })
_sym_db.RegisterMessage(WaitJobsResponse)

_JOBSERVICE = DESCRIPTOR.services_by_name['JobService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY._options = None
  _SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY._serialized_options = b'8\001'
  _SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY._options = None
  _SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _SCHEDULEJOBSCYPHERREQUEST._serialized_start=89
  _SCHEDULEJOBSCYPHERREQUEST._serialized_end=403
  _SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY._serialized_start=268
  _SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY._serialized_end=331
  _SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY._serialized_start=333
  _SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY._serialized_end=403
  _SCHEDULEJOBSCYPHERRESPONSE._serialized_start=405
  _SCHEDULEJOBSCYPHERRESPONSE._serialized_end=496
  _CANCELJOBSREQUEST._serialized_start=498
  _CANCELJOBSREQUEST._serialized_end=533
  _CANCELJOBSRESPONSE._serialized_start=535
  _CANCELJOBSRESPONSE._serialized_end=618
  _GETJOBSREQUEST._serialized_start=620
  _GETJOBSREQUEST._serialized_end=652
  _GETJOBSRESPONSE._serialized_start=654
  _GETJOBSRESPONSE._serialized_end=734
  _WAITJOBSREQUEST._serialized_start=736
  _WAITJOBSREQUEST._serialized_end=786
  _WAITJOBSRESPONSE._serialized_start=788
  _WAITJOBSRESPONSE._serialized_end=869
  _JOBSERVICE._serialized_start=872
  _JOBSERVICE._serialized_end=1155
# @@protoc_insertion_point(module_scope)
