# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AdminService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x41\x64minService.proto\x12\x03xgt\x1a\x13\x45rrorMessages.proto\"#\n\x0bStringArray\x12\x14\n\x0cstring_value\x18\x01 \x03(\t\"\x15\n\x04\x44\x61te\x12\r\n\x05value\x18\x01 \x01(\t\"\x15\n\x04Time\x12\r\n\x05value\x18\x01 \x01(\t\"\x19\n\x08\x44\x61teTime\x12\r\n\x05value\x18\x01 \x01(\t\"\x19\n\x08\x44uration\x12\r\n\x05value\x18\x01 \x01(\t\"\x1a\n\tIPAddress\x12\r\n\x05value\x18\x01 \x01(\t\"\xad\x02\n\tParameter\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x12\x1f\n\ndate_value\x18\x05 \x01(\x0b\x32\t.xgt.DateH\x00\x12\x1f\n\ntime_value\x18\x06 \x01(\x0b\x32\t.xgt.TimeH\x00\x12\'\n\x0e\x64\x61tetime_value\x18\x07 \x01(\x0b\x32\r.xgt.DateTimeH\x00\x12)\n\x0fipaddress_value\x18\x08 \x01(\x0b\x32\x0e.xgt.IPAddressH\x00\x12\'\n\x0e\x64uration_value\x18\t \x01(\x0b\x32\r.xgt.DurationH\x00\x42\x07\n\x05value\"/\n\x0eParameterValue\x12\x1d\n\x05value\x18\x01 \x03(\x0b\x32\x0e.xgt.Parameter\"p\n\x0b\x43onfigValue\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x42\x07\n\x05value\"D\n\x17\x43hangeErrorCountRequest\x12)\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x19.xgt.ErrorCountActionEnum\"J\n\x18\x43hangeErrorCountResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x13\n\x0b\x65rror_count\x18\x02 \x01(\x05\"\x1b\n\x19\x46reeUserMemorySizeRequest\"Q\n\x1a\x46reeUserMemorySizeResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x18\n\x10\x66ree_memory_size\x18\x02 \x01(\x03\"\x1a\n\x18MaxUserMemorySizeRequest\"I\n\x19MaxUserMemorySizeResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x11\n\tpool_size\x18\x02 \x01(\x03\" \n\x0fShutdownRequest\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\"-\n\x10ShutdownResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"\x10\n\x0eVersionRequest\"=\n\x0fVersionResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0f\n\x07version\x18\x02 \x01(\t\":\n\x13\x41uthenticateRequest\x12\x13\n\x0b\x63redentials\x18\x01 \x01(\t\x12\x0e\n\x06userid\x18\x02 \x01(\t\"H\n\x14\x41uthenticateResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x15\n\rsession_token\x18\x02 \x01(\t\"G\n\x1bKerberosAuthenticateRequest\x12\x11\n\tkrb_token\x18\x01 \x01(\x0c\x12\x15\n\rsession_token\x18\x02 \x01(\t\"c\n\x1cKerberosAuthenticateResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x15\n\rsession_token\x18\x02 \x01(\t\x12\x11\n\tkrb_token\x18\x03 \x01(\x0c\"\x15\n\x13\x43loseSessionRequest\"1\n\x14\x43loseSessionResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"\x1f\n\x10GetConfigRequest\x12\x0b\n\x03key\x18\x01 \x03(\t\"\xa6\x01\n\x11GetConfigResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x34\n\x07\x65ntries\x18\x02 \x03(\x0b\x32#.xgt.GetConfigResponse.EntriesEntry\x1a@\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\"\x89\x01\n\x10SetConfigRequest\x12\x33\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\".xgt.SetConfigRequest.EntriesEntry\x1a@\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\".\n\x11SetConfigResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"7\n\x1aSetDefaultNamespaceRequest\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x01 \x01(\t\"8\n\x1bSetDefaultNamespaceResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\"\x1c\n\x1aGetDefaultNamespaceRequest\"S\n\x1bGetDefaultNamespaceResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x02 \x01(\t*T\n\x14\x45rrorCountActionEnum\x12\x1e\n\x1aUNKNOWN_ERROR_COUNT_ACTION\x10\x00\x12\r\n\tINCREMENT\x10\x01\x12\r\n\tDECREMENT\x10\x02\x32\xa4\x07\n\x0c\x41\x64minService\x12Q\n\x10\x43hangeErrorCount\x12\x1c.xgt.ChangeErrorCountRequest\x1a\x1d.xgt.ChangeErrorCountResponse\"\x00\x12W\n\x12\x46reeUserMemorySize\x12\x1e.xgt.FreeUserMemorySizeRequest\x1a\x1f.xgt.FreeUserMemorySizeResponse\"\x00\x12T\n\x11MaxUserMemorySize\x12\x1d.xgt.MaxUserMemorySizeRequest\x1a\x1e.xgt.MaxUserMemorySizeResponse\"\x00\x12\x39\n\x08Shutdown\x12\x14.xgt.ShutdownRequest\x1a\x15.xgt.ShutdownResponse\"\x00\x12\x36\n\x07Version\x12\x13.xgt.VersionRequest\x1a\x14.xgt.VersionResponse\"\x00\x12\x45\n\x0c\x41uthenticate\x12\x18.xgt.AuthenticateRequest\x1a\x19.xgt.AuthenticateResponse\"\x00\x12]\n\x14KerberosAuthenticate\x12 .xgt.KerberosAuthenticateRequest\x1a!.xgt.KerberosAuthenticateResponse\"\x00\x12\x45\n\x0c\x43loseSession\x12\x18.xgt.CloseSessionRequest\x1a\x19.xgt.CloseSessionResponse\"\x00\x12<\n\tGetConfig\x12\x15.xgt.GetConfigRequest\x1a\x16.xgt.GetConfigResponse\"\x00\x12<\n\tSetConfig\x12\x15.xgt.SetConfigRequest\x1a\x16.xgt.SetConfigResponse\"\x00\x12Z\n\x13SetDefaultNamespace\x12\x1f.xgt.SetDefaultNamespaceRequest\x1a .xgt.SetDefaultNamespaceResponse\"\x00\x12Z\n\x13GetDefaultNamespace\x12\x1f.xgt.GetDefaultNamespaceRequest\x1a .xgt.GetDefaultNamespaceResponse\"\x00\x62\x06proto3')

_ERRORCOUNTACTIONENUM = DESCRIPTOR.enum_types_by_name['ErrorCountActionEnum']
ErrorCountActionEnum = enum_type_wrapper.EnumTypeWrapper(_ERRORCOUNTACTIONENUM)
UNKNOWN_ERROR_COUNT_ACTION = 0
INCREMENT = 1
DECREMENT = 2


_STRINGARRAY = DESCRIPTOR.message_types_by_name['StringArray']
_DATE = DESCRIPTOR.message_types_by_name['Date']
_TIME = DESCRIPTOR.message_types_by_name['Time']
_DATETIME = DESCRIPTOR.message_types_by_name['DateTime']
_DURATION = DESCRIPTOR.message_types_by_name['Duration']
_IPADDRESS = DESCRIPTOR.message_types_by_name['IPAddress']
_PARAMETER = DESCRIPTOR.message_types_by_name['Parameter']
_PARAMETERVALUE = DESCRIPTOR.message_types_by_name['ParameterValue']
_CONFIGVALUE = DESCRIPTOR.message_types_by_name['ConfigValue']
_CHANGEERRORCOUNTREQUEST = DESCRIPTOR.message_types_by_name['ChangeErrorCountRequest']
_CHANGEERRORCOUNTRESPONSE = DESCRIPTOR.message_types_by_name['ChangeErrorCountResponse']
_FREEUSERMEMORYSIZEREQUEST = DESCRIPTOR.message_types_by_name['FreeUserMemorySizeRequest']
_FREEUSERMEMORYSIZERESPONSE = DESCRIPTOR.message_types_by_name['FreeUserMemorySizeResponse']
_MAXUSERMEMORYSIZEREQUEST = DESCRIPTOR.message_types_by_name['MaxUserMemorySizeRequest']
_MAXUSERMEMORYSIZERESPONSE = DESCRIPTOR.message_types_by_name['MaxUserMemorySizeResponse']
_SHUTDOWNREQUEST = DESCRIPTOR.message_types_by_name['ShutdownRequest']
_SHUTDOWNRESPONSE = DESCRIPTOR.message_types_by_name['ShutdownResponse']
_VERSIONREQUEST = DESCRIPTOR.message_types_by_name['VersionRequest']
_VERSIONRESPONSE = DESCRIPTOR.message_types_by_name['VersionResponse']
_AUTHENTICATEREQUEST = DESCRIPTOR.message_types_by_name['AuthenticateRequest']
_AUTHENTICATERESPONSE = DESCRIPTOR.message_types_by_name['AuthenticateResponse']
_KERBEROSAUTHENTICATEREQUEST = DESCRIPTOR.message_types_by_name['KerberosAuthenticateRequest']
_KERBEROSAUTHENTICATERESPONSE = DESCRIPTOR.message_types_by_name['KerberosAuthenticateResponse']
_CLOSESESSIONREQUEST = DESCRIPTOR.message_types_by_name['CloseSessionRequest']
_CLOSESESSIONRESPONSE = DESCRIPTOR.message_types_by_name['CloseSessionResponse']
_GETCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetConfigRequest']
_GETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['GetConfigResponse']
_GETCONFIGRESPONSE_ENTRIESENTRY = _GETCONFIGRESPONSE.nested_types_by_name['EntriesEntry']
_SETCONFIGREQUEST = DESCRIPTOR.message_types_by_name['SetConfigRequest']
_SETCONFIGREQUEST_ENTRIESENTRY = _SETCONFIGREQUEST.nested_types_by_name['EntriesEntry']
_SETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['SetConfigResponse']
_SETDEFAULTNAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['SetDefaultNamespaceRequest']
_SETDEFAULTNAMESPACERESPONSE = DESCRIPTOR.message_types_by_name['SetDefaultNamespaceResponse']
_GETDEFAULTNAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['GetDefaultNamespaceRequest']
_GETDEFAULTNAMESPACERESPONSE = DESCRIPTOR.message_types_by_name['GetDefaultNamespaceResponse']
StringArray = _reflection.GeneratedProtocolMessageType('StringArray', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAY,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.StringArray)
  })
_sym_db.RegisterMessage(StringArray)

Date = _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
  'DESCRIPTOR' : _DATE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Date)
  })
_sym_db.RegisterMessage(Date)

Time = _reflection.GeneratedProtocolMessageType('Time', (_message.Message,), {
  'DESCRIPTOR' : _TIME,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Time)
  })
_sym_db.RegisterMessage(Time)

DateTime = _reflection.GeneratedProtocolMessageType('DateTime', (_message.Message,), {
  'DESCRIPTOR' : _DATETIME,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DateTime)
  })
_sym_db.RegisterMessage(DateTime)

Duration = _reflection.GeneratedProtocolMessageType('Duration', (_message.Message,), {
  'DESCRIPTOR' : _DURATION,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Duration)
  })
_sym_db.RegisterMessage(Duration)

IPAddress = _reflection.GeneratedProtocolMessageType('IPAddress', (_message.Message,), {
  'DESCRIPTOR' : _IPADDRESS,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IPAddress)
  })
_sym_db.RegisterMessage(IPAddress)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETER,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.Parameter)
  })
_sym_db.RegisterMessage(Parameter)

ParameterValue = _reflection.GeneratedProtocolMessageType('ParameterValue', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERVALUE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ParameterValue)
  })
_sym_db.RegisterMessage(ParameterValue)

ConfigValue = _reflection.GeneratedProtocolMessageType('ConfigValue', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGVALUE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ConfigValue)
  })
_sym_db.RegisterMessage(ConfigValue)

ChangeErrorCountRequest = _reflection.GeneratedProtocolMessageType('ChangeErrorCountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEERRORCOUNTREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ChangeErrorCountRequest)
  })
_sym_db.RegisterMessage(ChangeErrorCountRequest)

ChangeErrorCountResponse = _reflection.GeneratedProtocolMessageType('ChangeErrorCountResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEERRORCOUNTRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ChangeErrorCountResponse)
  })
_sym_db.RegisterMessage(ChangeErrorCountResponse)

FreeUserMemorySizeRequest = _reflection.GeneratedProtocolMessageType('FreeUserMemorySizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _FREEUSERMEMORYSIZEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FreeUserMemorySizeRequest)
  })
_sym_db.RegisterMessage(FreeUserMemorySizeRequest)

FreeUserMemorySizeResponse = _reflection.GeneratedProtocolMessageType('FreeUserMemorySizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _FREEUSERMEMORYSIZERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FreeUserMemorySizeResponse)
  })
_sym_db.RegisterMessage(FreeUserMemorySizeResponse)

MaxUserMemorySizeRequest = _reflection.GeneratedProtocolMessageType('MaxUserMemorySizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _MAXUSERMEMORYSIZEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MaxUserMemorySizeRequest)
  })
_sym_db.RegisterMessage(MaxUserMemorySizeRequest)

MaxUserMemorySizeResponse = _reflection.GeneratedProtocolMessageType('MaxUserMemorySizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _MAXUSERMEMORYSIZERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.MaxUserMemorySizeResponse)
  })
_sym_db.RegisterMessage(MaxUserMemorySizeResponse)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ShutdownRequest)
  })
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ShutdownResponse)
  })
_sym_db.RegisterMessage(ShutdownResponse)

VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VersionRequest)
  })
_sym_db.RegisterMessage(VersionRequest)

VersionResponse = _reflection.GeneratedProtocolMessageType('VersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.VersionResponse)
  })
_sym_db.RegisterMessage(VersionResponse)

AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.AuthenticateRequest)
  })
_sym_db.RegisterMessage(AuthenticateRequest)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.AuthenticateResponse)
  })
_sym_db.RegisterMessage(AuthenticateResponse)

KerberosAuthenticateRequest = _reflection.GeneratedProtocolMessageType('KerberosAuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _KERBEROSAUTHENTICATEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.KerberosAuthenticateRequest)
  })
_sym_db.RegisterMessage(KerberosAuthenticateRequest)

KerberosAuthenticateResponse = _reflection.GeneratedProtocolMessageType('KerberosAuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _KERBEROSAUTHENTICATERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.KerberosAuthenticateResponse)
  })
_sym_db.RegisterMessage(KerberosAuthenticateResponse)

CloseSessionRequest = _reflection.GeneratedProtocolMessageType('CloseSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOSESESSIONREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CloseSessionRequest)
  })
_sym_db.RegisterMessage(CloseSessionRequest)

CloseSessionResponse = _reflection.GeneratedProtocolMessageType('CloseSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLOSESESSIONRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.CloseSessionResponse)
  })
_sym_db.RegisterMessage(CloseSessionResponse)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetConfigRequest)
  })
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {

  'EntriesEntry' : _reflection.GeneratedProtocolMessageType('EntriesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCONFIGRESPONSE_ENTRIESENTRY,
    '__module__' : 'AdminService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.GetConfigResponse.EntriesEntry)
    })
  ,
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)
_sym_db.RegisterMessage(GetConfigResponse.EntriesEntry)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), {

  'EntriesEntry' : _reflection.GeneratedProtocolMessageType('EntriesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SETCONFIGREQUEST_ENTRIESENTRY,
    '__module__' : 'AdminService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.SetConfigRequest.EntriesEntry)
    })
  ,
  'DESCRIPTOR' : _SETCONFIGREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetConfigRequest)
  })
_sym_db.RegisterMessage(SetConfigRequest)
_sym_db.RegisterMessage(SetConfigRequest.EntriesEntry)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetConfigResponse)
  })
_sym_db.RegisterMessage(SetConfigResponse)

SetDefaultNamespaceRequest = _reflection.GeneratedProtocolMessageType('SetDefaultNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDEFAULTNAMESPACEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetDefaultNamespaceRequest)
  })
_sym_db.RegisterMessage(SetDefaultNamespaceRequest)

SetDefaultNamespaceResponse = _reflection.GeneratedProtocolMessageType('SetDefaultNamespaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETDEFAULTNAMESPACERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SetDefaultNamespaceResponse)
  })
_sym_db.RegisterMessage(SetDefaultNamespaceResponse)

GetDefaultNamespaceRequest = _reflection.GeneratedProtocolMessageType('GetDefaultNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDEFAULTNAMESPACEREQUEST,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetDefaultNamespaceRequest)
  })
_sym_db.RegisterMessage(GetDefaultNamespaceRequest)

GetDefaultNamespaceResponse = _reflection.GeneratedProtocolMessageType('GetDefaultNamespaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDEFAULTNAMESPACERESPONSE,
  '__module__' : 'AdminService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.GetDefaultNamespaceResponse)
  })
_sym_db.RegisterMessage(GetDefaultNamespaceResponse)

_ADMINSERVICE = DESCRIPTOR.services_by_name['AdminService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETCONFIGRESPONSE_ENTRIESENTRY._options = None
  _GETCONFIGRESPONSE_ENTRIESENTRY._serialized_options = b'8\001'
  _SETCONFIGREQUEST_ENTRIESENTRY._options = None
  _SETCONFIGREQUEST_ENTRIESENTRY._serialized_options = b'8\001'
  _ERRORCOUNTACTIONENUM._serialized_start=2205
  _ERRORCOUNTACTIONENUM._serialized_end=2289
  _STRINGARRAY._serialized_start=48
  _STRINGARRAY._serialized_end=83
  _DATE._serialized_start=85
  _DATE._serialized_end=106
  _TIME._serialized_start=108
  _TIME._serialized_end=129
  _DATETIME._serialized_start=131
  _DATETIME._serialized_end=156
  _DURATION._serialized_start=158
  _DURATION._serialized_end=183
  _IPADDRESS._serialized_start=185
  _IPADDRESS._serialized_end=211
  _PARAMETER._serialized_start=214
  _PARAMETER._serialized_end=515
  _PARAMETERVALUE._serialized_start=517
  _PARAMETERVALUE._serialized_end=564
  _CONFIGVALUE._serialized_start=566
  _CONFIGVALUE._serialized_end=678
  _CHANGEERRORCOUNTREQUEST._serialized_start=680
  _CHANGEERRORCOUNTREQUEST._serialized_end=748
  _CHANGEERRORCOUNTRESPONSE._serialized_start=750
  _CHANGEERRORCOUNTRESPONSE._serialized_end=824
  _FREEUSERMEMORYSIZEREQUEST._serialized_start=826
  _FREEUSERMEMORYSIZEREQUEST._serialized_end=853
  _FREEUSERMEMORYSIZERESPONSE._serialized_start=855
  _FREEUSERMEMORYSIZERESPONSE._serialized_end=936
  _MAXUSERMEMORYSIZEREQUEST._serialized_start=938
  _MAXUSERMEMORYSIZEREQUEST._serialized_end=964
  _MAXUSERMEMORYSIZERESPONSE._serialized_start=966
  _MAXUSERMEMORYSIZERESPONSE._serialized_end=1039
  _SHUTDOWNREQUEST._serialized_start=1041
  _SHUTDOWNREQUEST._serialized_end=1073
  _SHUTDOWNRESPONSE._serialized_start=1075
  _SHUTDOWNRESPONSE._serialized_end=1120
  _VERSIONREQUEST._serialized_start=1122
  _VERSIONREQUEST._serialized_end=1138
  _VERSIONRESPONSE._serialized_start=1140
  _VERSIONRESPONSE._serialized_end=1201
  _AUTHENTICATEREQUEST._serialized_start=1203
  _AUTHENTICATEREQUEST._serialized_end=1261
  _AUTHENTICATERESPONSE._serialized_start=1263
  _AUTHENTICATERESPONSE._serialized_end=1335
  _KERBEROSAUTHENTICATEREQUEST._serialized_start=1337
  _KERBEROSAUTHENTICATEREQUEST._serialized_end=1408
  _KERBEROSAUTHENTICATERESPONSE._serialized_start=1410
  _KERBEROSAUTHENTICATERESPONSE._serialized_end=1509
  _CLOSESESSIONREQUEST._serialized_start=1511
  _CLOSESESSIONREQUEST._serialized_end=1532
  _CLOSESESSIONRESPONSE._serialized_start=1534
  _CLOSESESSIONRESPONSE._serialized_end=1583
  _GETCONFIGREQUEST._serialized_start=1585
  _GETCONFIGREQUEST._serialized_end=1616
  _GETCONFIGRESPONSE._serialized_start=1619
  _GETCONFIGRESPONSE._serialized_end=1785
  _GETCONFIGRESPONSE_ENTRIESENTRY._serialized_start=1721
  _GETCONFIGRESPONSE_ENTRIESENTRY._serialized_end=1785
  _SETCONFIGREQUEST._serialized_start=1788
  _SETCONFIGREQUEST._serialized_end=1925
  _SETCONFIGREQUEST_ENTRIESENTRY._serialized_start=1721
  _SETCONFIGREQUEST_ENTRIESENTRY._serialized_end=1785
  _SETCONFIGRESPONSE._serialized_start=1927
  _SETCONFIGRESPONSE._serialized_end=1973
  _SETDEFAULTNAMESPACEREQUEST._serialized_start=1975
  _SETDEFAULTNAMESPACEREQUEST._serialized_end=2030
  _SETDEFAULTNAMESPACERESPONSE._serialized_start=2032
  _SETDEFAULTNAMESPACERESPONSE._serialized_end=2088
  _GETDEFAULTNAMESPACEREQUEST._serialized_start=2090
  _GETDEFAULTNAMESPACEREQUEST._serialized_end=2118
  _GETDEFAULTNAMESPACERESPONSE._serialized_start=2120
  _GETDEFAULTNAMESPACERESPONSE._serialized_end=2203
  _ADMINSERVICE._serialized_start=2292
  _ADMINSERVICE._serialized_end=3224
# @@protoc_insertion_point(module_scope)
