# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DataService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import AdminService_pb2 as AdminService__pb2
from . import ErrorMessages_pb2 as ErrorMessages__pb2
from . import SchemaMessages_pb2 as SchemaMessages__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x44\x61taService.proto\x12\x03xgt\x1a\x12\x41\x64minService.proto\x1a\x13\x45rrorMessages.proto\x1a\x14SchemaMessages.proto\x1a\x1egoogle/protobuf/wrappers.proto\"N\n\x17\x46rameColumnToSourceName\x12\x19\n\x11\x66rame_column_name\x18\x01 \x01(\t\x12\x18\n\x10\x66ile_column_name\x18\x02 \x01(\t\"L\n\x16\x46rameColumnToSourceIdx\x12\x19\n\x11\x66rame_column_name\x18\x01 \x01(\t\x12\x17\n\x0f\x66ile_column_idx\x18\x02 \x01(\x04\"\xa8\x01\n\rColumnMapping\x12\x41\n\x1b\x66rame_column_to_source_name\x18\x01 \x03(\x0b\x32\x1c.xgt.FrameColumnToSourceName\x12?\n\x1a\x66rame_column_to_source_idx\x18\x02 \x03(\x0b\x32\x1b.xgt.FrameColumnToSourceIdx\x12\x13\n\x0bhas_mapping\x18\x03 \x01(\x08\"\xb1\x01\n\x17UploadRowLevelLabelInfo\x12\x0e\n\x06labels\x18\x01 \x03(\t\x12\x1c\n\x14label_column_indices\x18\x02 \x03(\x03\x12\x1a\n\x12label_column_names\x18\x03 \x03(\t\x12%\n\x1dimplicit_source_vertex_labels\x18\x04 \x03(\t\x12%\n\x1dimplicit_target_vertex_labels\x18\x05 \x03(\t\"L\n\x19\x44ownloadRowLevelLabelInfo\x12\x14\n\x0c\x65gest_labels\x18\x01 \x01(\x08\x12\x19\n\x11label_header_name\x18\x02 \x01(\t\"\x8e\x03\n\x11UploadDataRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12&\n\x0c\x63ontent_type\x18\x02 \x01(\x0e\x32\x10.xgt.ContentType\x12(\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x13.xgt.HeaderModeEnum\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\x12\x15\n\rauthorization\x18\x05 \x01(\t\x12\x19\n\x11implicit_vertices\x18\x06 \x01(\x08\x12\x30\n\nrow_labels\x18\x07 \x01(\x0b\x32\x1c.xgt.UploadRowLevelLabelInfo\x12\x11\n\tdelimiter\x18\x08 \x01(\t\x12\x18\n\x10is_python_insert\x18\t \x01(\x08\x12\x11\n\tfile_path\x18\n \x01(\t\x12*\n\x0e\x63olumn_mapping\x18\x0b \x01(\x0b\x32\x12.xgt.ColumnMapping\x12\x17\n\x0fsuppress_errors\x18\x0c \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\r \x01(\t\"S\n\x12UploadDataResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x01(\x0b\x32\x0e.xgt.JobStatus\"\xc5\x02\n\x13\x44ownloadDataRequest\x12\x17\n\x0frepository_name\x18\x01 \x01(\t\x12,\n\x06offset\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x06length\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x14\n\x0cwith_headers\x18\x04 \x01(\x08\x12&\n\x0c\x63ontent_type\x18\x05 \x01(\x0e\x32\x10.xgt.ContentType\x12\x32\n\nrow_labels\x18\x08 \x01(\x0b\x32\x1e.xgt.DownloadRowLevelLabelInfo\x12\x16\n\x0epreserve_order\x18\t \x01(\x08\x12\x1c\n\x14\x64uration_as_interval\x18\n \x01(\x08\x12\x11\n\tdelimiter\x18\x0b \x01(\t\"~\n\x14\x44ownloadDataResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\"\n\njob_status\x18\x03 \x01(\x0b\x32\x0e.xgt.JobStatus\x12\x16\n\x0enum_row_labels\x18\x04 \x01(\x05\"\xb0\x03\n\x10IngestUriRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontent_uri\x18\x02 \x03(\t\x12(\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x13.xgt.HeaderModeEnum\x12\x15\n\rauthorization\x18\x04 \x01(\t\x12\x19\n\x11implicit_vertices\x18\x05 \x01(\x08\x12\x31\n\x06kwargs\x18\x06 \x03(\x0b\x32!.xgt.IngestUriRequest.KwargsEntry\x12\x30\n\nrow_labels\x18\x07 \x01(\x0b\x32\x1c.xgt.UploadRowLevelLabelInfo\x12\x11\n\tdelimiter\x18\x08 \x01(\t\x12*\n\x0e\x63olumn_mapping\x18\t \x01(\x0b\x32\x12.xgt.ColumnMapping\x12\x17\n\x0fsuppress_errors\x18\n \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\x0b \x01(\t\x1a?\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\"R\n\x11IngestUriResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x01(\x0b\x32\x0e.xgt.JobStatus\"\xb3\x03\n\x0f\x45gestUriRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x14\n\x0cwith_headers\x18\x03 \x01(\x08\x12\x30\n\x06kwargs\x18\x04 \x03(\x0b\x32 .xgt.EgestUriRequest.KwargsEntry\x12\x32\n\nrow_labels\x18\x05 \x01(\x0b\x32\x1e.xgt.DownloadRowLevelLabelInfo\x12\x16\n\x0epreserve_order\x18\x06 \x01(\x08\x12\x17\n\x0fnumber_of_files\x18\x07 \x01(\x04\x12,\n\x06offset\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x06length\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1c\n\x14\x64uration_as_interval\x18\n \x01(\x08\x12\x11\n\tdelimiter\x18\x0b \x01(\t\x1a?\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.xgt.ConfigValue:\x02\x38\x01\"Q\n\x10\x45gestUriResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x01(\x0b\x32\x0e.xgt.JobStatus\"d\n\x12InferSchemaRequest\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12(\n\x0bheader_mode\x18\x02 \x01(\x0e\x32\x13.xgt.HeaderModeEnum\x12\x11\n\tdelimiter\x18\x03 \x01(\t\"M\n\x13InferSchemaResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\x1b\n\x06schema\x18\x02 \x01(\x0b\x32\x0b.xgt.Schema\"m\n\x07SSLInfo\x12\x0e\n\x06\x64o_ssl\x18\x01 \x01(\x08\x12\x12\n\nchain_cert\x18\x02 \x01(\x0c\x12\x12\n\nclient_key\x18\x03 \x01(\x0c\x12\x13\n\x0b\x63lient_cert\x18\x04 \x01(\x0c\x12\x15\n\rssl_server_cn\x18\x05 \x01(\t\"3\n\x0cUserAuthInfo\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x97\x01\n\x1fTransferFrameArrowClientRequest\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x04\x12\x17\n\x0frepository_name\x18\x03 \x01(\t\x12\x19\n\x03ssl\x18\x04 \x01(\x0b\x32\x0c.xgt.SSLInfo\x12$\n\tuser_auth\x18\x05 \x01(\x0b\x32\x11.xgt.UserAuthInfo\"a\n TransferFrameArrowClientResponse\x12\x19\n\x05\x65rror\x18\x01 \x03(\x0b\x32\n.xgt.Error\x12\"\n\njob_status\x18\x02 \x01(\x0b\x32\x0e.xgt.JobStatus*_\n\x0eHeaderModeEnum\x12\x17\n\x13UNKNOWN_HEADER_MODE\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x12\n\x0eIGNORE_HEADERS\x10\x02\x12\n\n\x06NORMAL\x10\x03\x12\n\n\x06STRICT\x10\x04*R\n\x0b\x43ontentType\x12\x13\n\x0fUNKNOWN_CONTENT\x10\x00\x12\x07\n\x03\x43SV\x10\x01\x12\x08\n\x04JSON\x10\x02\x12\x07\n\x03ZIP\x10\x03\x12\x08\n\x04GZIP\x10\x04\x12\x08\n\x04TZIP\x10\x05\x32\xc1\x03\n\x0b\x44\x61taService\x12\x41\n\nUploadData\x12\x16.xgt.UploadDataRequest\x1a\x17.xgt.UploadDataResponse\"\x00(\x01\x12G\n\x0c\x44ownloadData\x12\x18.xgt.DownloadDataRequest\x1a\x19.xgt.DownloadDataResponse\"\x00\x30\x01\x12<\n\tIngestUri\x12\x15.xgt.IngestUriRequest\x1a\x16.xgt.IngestUriResponse\"\x00\x12\x39\n\x08\x45gestUri\x12\x14.xgt.EgestUriRequest\x1a\x15.xgt.EgestUriResponse\"\x00\x12\x42\n\x0bInferSchema\x12\x17.xgt.InferSchemaRequest\x1a\x18.xgt.InferSchemaResponse\"\x00\x12i\n\x18TransferFrameArrowClient\x12$.xgt.TransferFrameArrowClientRequest\x1a%.xgt.TransferFrameArrowClientResponse\"\x00\x62\x06proto3')

_HEADERMODEENUM = DESCRIPTOR.enum_types_by_name['HeaderModeEnum']
HeaderModeEnum = enum_type_wrapper.EnumTypeWrapper(_HEADERMODEENUM)
_CONTENTTYPE = DESCRIPTOR.enum_types_by_name['ContentType']
ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
UNKNOWN_HEADER_MODE = 0
NONE = 1
IGNORE_HEADERS = 2
NORMAL = 3
STRICT = 4
UNKNOWN_CONTENT = 0
CSV = 1
JSON = 2
ZIP = 3
GZIP = 4
TZIP = 5


_FRAMECOLUMNTOSOURCENAME = DESCRIPTOR.message_types_by_name['FrameColumnToSourceName']
_FRAMECOLUMNTOSOURCEIDX = DESCRIPTOR.message_types_by_name['FrameColumnToSourceIdx']
_COLUMNMAPPING = DESCRIPTOR.message_types_by_name['ColumnMapping']
_UPLOADROWLEVELLABELINFO = DESCRIPTOR.message_types_by_name['UploadRowLevelLabelInfo']
_DOWNLOADROWLEVELLABELINFO = DESCRIPTOR.message_types_by_name['DownloadRowLevelLabelInfo']
_UPLOADDATAREQUEST = DESCRIPTOR.message_types_by_name['UploadDataRequest']
_UPLOADDATARESPONSE = DESCRIPTOR.message_types_by_name['UploadDataResponse']
_DOWNLOADDATAREQUEST = DESCRIPTOR.message_types_by_name['DownloadDataRequest']
_DOWNLOADDATARESPONSE = DESCRIPTOR.message_types_by_name['DownloadDataResponse']
_INGESTURIREQUEST = DESCRIPTOR.message_types_by_name['IngestUriRequest']
_INGESTURIREQUEST_KWARGSENTRY = _INGESTURIREQUEST.nested_types_by_name['KwargsEntry']
_INGESTURIRESPONSE = DESCRIPTOR.message_types_by_name['IngestUriResponse']
_EGESTURIREQUEST = DESCRIPTOR.message_types_by_name['EgestUriRequest']
_EGESTURIREQUEST_KWARGSENTRY = _EGESTURIREQUEST.nested_types_by_name['KwargsEntry']
_EGESTURIRESPONSE = DESCRIPTOR.message_types_by_name['EgestUriResponse']
_INFERSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['InferSchemaRequest']
_INFERSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['InferSchemaResponse']
_SSLINFO = DESCRIPTOR.message_types_by_name['SSLInfo']
_USERAUTHINFO = DESCRIPTOR.message_types_by_name['UserAuthInfo']
_TRANSFERFRAMEARROWCLIENTREQUEST = DESCRIPTOR.message_types_by_name['TransferFrameArrowClientRequest']
_TRANSFERFRAMEARROWCLIENTRESPONSE = DESCRIPTOR.message_types_by_name['TransferFrameArrowClientResponse']
FrameColumnToSourceName = _reflection.GeneratedProtocolMessageType('FrameColumnToSourceName', (_message.Message,), {
  'DESCRIPTOR' : _FRAMECOLUMNTOSOURCENAME,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FrameColumnToSourceName)
  })
_sym_db.RegisterMessage(FrameColumnToSourceName)

FrameColumnToSourceIdx = _reflection.GeneratedProtocolMessageType('FrameColumnToSourceIdx', (_message.Message,), {
  'DESCRIPTOR' : _FRAMECOLUMNTOSOURCEIDX,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.FrameColumnToSourceIdx)
  })
_sym_db.RegisterMessage(FrameColumnToSourceIdx)

ColumnMapping = _reflection.GeneratedProtocolMessageType('ColumnMapping', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNMAPPING,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.ColumnMapping)
  })
_sym_db.RegisterMessage(ColumnMapping)

UploadRowLevelLabelInfo = _reflection.GeneratedProtocolMessageType('UploadRowLevelLabelInfo', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADROWLEVELLABELINFO,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UploadRowLevelLabelInfo)
  })
_sym_db.RegisterMessage(UploadRowLevelLabelInfo)

DownloadRowLevelLabelInfo = _reflection.GeneratedProtocolMessageType('DownloadRowLevelLabelInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADROWLEVELLABELINFO,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DownloadRowLevelLabelInfo)
  })
_sym_db.RegisterMessage(DownloadRowLevelLabelInfo)

UploadDataRequest = _reflection.GeneratedProtocolMessageType('UploadDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDATAREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UploadDataRequest)
  })
_sym_db.RegisterMessage(UploadDataRequest)

UploadDataResponse = _reflection.GeneratedProtocolMessageType('UploadDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDATARESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UploadDataResponse)
  })
_sym_db.RegisterMessage(UploadDataResponse)

DownloadDataRequest = _reflection.GeneratedProtocolMessageType('DownloadDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDATAREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DownloadDataRequest)
  })
_sym_db.RegisterMessage(DownloadDataRequest)

DownloadDataResponse = _reflection.GeneratedProtocolMessageType('DownloadDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDATARESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.DownloadDataResponse)
  })
_sym_db.RegisterMessage(DownloadDataResponse)

IngestUriRequest = _reflection.GeneratedProtocolMessageType('IngestUriRequest', (_message.Message,), {

  'KwargsEntry' : _reflection.GeneratedProtocolMessageType('KwargsEntry', (_message.Message,), {
    'DESCRIPTOR' : _INGESTURIREQUEST_KWARGSENTRY,
    '__module__' : 'DataService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.IngestUriRequest.KwargsEntry)
    })
  ,
  'DESCRIPTOR' : _INGESTURIREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IngestUriRequest)
  })
_sym_db.RegisterMessage(IngestUriRequest)
_sym_db.RegisterMessage(IngestUriRequest.KwargsEntry)

IngestUriResponse = _reflection.GeneratedProtocolMessageType('IngestUriResponse', (_message.Message,), {
  'DESCRIPTOR' : _INGESTURIRESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.IngestUriResponse)
  })
_sym_db.RegisterMessage(IngestUriResponse)

EgestUriRequest = _reflection.GeneratedProtocolMessageType('EgestUriRequest', (_message.Message,), {

  'KwargsEntry' : _reflection.GeneratedProtocolMessageType('KwargsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EGESTURIREQUEST_KWARGSENTRY,
    '__module__' : 'DataService_pb2'
    # @@protoc_insertion_point(class_scope:xgt.EgestUriRequest.KwargsEntry)
    })
  ,
  'DESCRIPTOR' : _EGESTURIREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.EgestUriRequest)
  })
_sym_db.RegisterMessage(EgestUriRequest)
_sym_db.RegisterMessage(EgestUriRequest.KwargsEntry)

EgestUriResponse = _reflection.GeneratedProtocolMessageType('EgestUriResponse', (_message.Message,), {
  'DESCRIPTOR' : _EGESTURIRESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.EgestUriResponse)
  })
_sym_db.RegisterMessage(EgestUriResponse)

InferSchemaRequest = _reflection.GeneratedProtocolMessageType('InferSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _INFERSCHEMAREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.InferSchemaRequest)
  })
_sym_db.RegisterMessage(InferSchemaRequest)

InferSchemaResponse = _reflection.GeneratedProtocolMessageType('InferSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _INFERSCHEMARESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.InferSchemaResponse)
  })
_sym_db.RegisterMessage(InferSchemaResponse)

SSLInfo = _reflection.GeneratedProtocolMessageType('SSLInfo', (_message.Message,), {
  'DESCRIPTOR' : _SSLINFO,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.SSLInfo)
  })
_sym_db.RegisterMessage(SSLInfo)

UserAuthInfo = _reflection.GeneratedProtocolMessageType('UserAuthInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERAUTHINFO,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.UserAuthInfo)
  })
_sym_db.RegisterMessage(UserAuthInfo)

TransferFrameArrowClientRequest = _reflection.GeneratedProtocolMessageType('TransferFrameArrowClientRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERFRAMEARROWCLIENTREQUEST,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.TransferFrameArrowClientRequest)
  })
_sym_db.RegisterMessage(TransferFrameArrowClientRequest)

TransferFrameArrowClientResponse = _reflection.GeneratedProtocolMessageType('TransferFrameArrowClientResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERFRAMEARROWCLIENTRESPONSE,
  '__module__' : 'DataService_pb2'
  # @@protoc_insertion_point(class_scope:xgt.TransferFrameArrowClientResponse)
  })
_sym_db.RegisterMessage(TransferFrameArrowClientResponse)

_DATASERVICE = DESCRIPTOR.services_by_name['DataService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INGESTURIREQUEST_KWARGSENTRY._options = None
  _INGESTURIREQUEST_KWARGSENTRY._serialized_options = b'8\001'
  _EGESTURIREQUEST_KWARGSENTRY._options = None
  _EGESTURIREQUEST_KWARGSENTRY._serialized_options = b'8\001'
  _HEADERMODEENUM._serialized_start=3288
  _HEADERMODEENUM._serialized_end=3383
  _CONTENTTYPE._serialized_start=3385
  _CONTENTTYPE._serialized_end=3467
  _FRAMECOLUMNTOSOURCENAME._serialized_start=121
  _FRAMECOLUMNTOSOURCENAME._serialized_end=199
  _FRAMECOLUMNTOSOURCEIDX._serialized_start=201
  _FRAMECOLUMNTOSOURCEIDX._serialized_end=277
  _COLUMNMAPPING._serialized_start=280
  _COLUMNMAPPING._serialized_end=448
  _UPLOADROWLEVELLABELINFO._serialized_start=451
  _UPLOADROWLEVELLABELINFO._serialized_end=628
  _DOWNLOADROWLEVELLABELINFO._serialized_start=630
  _DOWNLOADROWLEVELLABELINFO._serialized_end=706
  _UPLOADDATAREQUEST._serialized_start=709
  _UPLOADDATAREQUEST._serialized_end=1107
  _UPLOADDATARESPONSE._serialized_start=1109
  _UPLOADDATARESPONSE._serialized_end=1192
  _DOWNLOADDATAREQUEST._serialized_start=1195
  _DOWNLOADDATAREQUEST._serialized_end=1520
  _DOWNLOADDATARESPONSE._serialized_start=1522
  _DOWNLOADDATARESPONSE._serialized_end=1648
  _INGESTURIREQUEST._serialized_start=1651
  _INGESTURIREQUEST._serialized_end=2083
  _INGESTURIREQUEST_KWARGSENTRY._serialized_start=2020
  _INGESTURIREQUEST_KWARGSENTRY._serialized_end=2083
  _INGESTURIRESPONSE._serialized_start=2085
  _INGESTURIRESPONSE._serialized_end=2167
  _EGESTURIREQUEST._serialized_start=2170
  _EGESTURIREQUEST._serialized_end=2605
  _EGESTURIREQUEST_KWARGSENTRY._serialized_start=2020
  _EGESTURIREQUEST_KWARGSENTRY._serialized_end=2083
  _EGESTURIRESPONSE._serialized_start=2607
  _EGESTURIRESPONSE._serialized_end=2688
  _INFERSCHEMAREQUEST._serialized_start=2690
  _INFERSCHEMAREQUEST._serialized_end=2790
  _INFERSCHEMARESPONSE._serialized_start=2792
  _INFERSCHEMARESPONSE._serialized_end=2869
  _SSLINFO._serialized_start=2871
  _SSLINFO._serialized_end=2980
  _USERAUTHINFO._serialized_start=2982
  _USERAUTHINFO._serialized_end=3033
  _TRANSFERFRAMEARROWCLIENTREQUEST._serialized_start=3036
  _TRANSFERFRAMEARROWCLIENTREQUEST._serialized_end=3187
  _TRANSFERFRAMEARROWCLIENTRESPONSE._serialized_start=3189
  _TRANSFERFRAMEARROWCLIENTRESPONSE._serialized_end=3286
  _DATASERVICE._serialized_start=3470
  _DATASERVICE._serialized_end=3919
# @@protoc_insertion_point(module_scope)
